raytraverse.renderer
==========================================================

.. raw:: html
   :file: _static/renderer2.html


ImageRenderer
--------------------------------

.. autoclass:: raytraverse.renderer.ImageRenderer
    :members:
    :undoc-members:
    :show-inheritance:

SpRenderer
--------------------------------

.. autoclass:: raytraverse.renderer.SpRenderer
    :members:
    :undoc-members:
    :show-inheritance:
